# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](http://keepachangelog.com/en/1.0.0/)
and this project adheres to [Semantic Versioning](http://semver.org/spec/v2.0.0.html).

<!-- insertion marker -->
## [v0.1.0](https://github.com/galihanggara68/clickshot/releases/tag/v0.1.0) - 2025-08-07

<small>[Compare with first commit](https://github.com/galihanggara68/clickshot/compare/91c14d4d4af8edc6ac170970951cb8fd6066c1b7...v0.1.0)</small>

